.. redirect-from:: /users/prev_whats_new/github_stats_3.8.2

.. _github-stats-3-8-2:

GitHub statistics for 3.8.2 (Nov 17, 2023)
==========================================

GitHub statistics for 2023/10/31 (tag: v3.8.1) - 2023/11/17

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 3 issues and merged 27 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/86?closed=1>`__

The following 10 authors contributed 39 commits.

* Antony Lee
* dohyun
* Elliott Sales de Andrade
* hannah
* Jody Klymak
* Kyle Sunden
* Oscar Gustafsson
* Ruth Comer
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (27):

* :ghpull:`27339`: Backport PR #27299 on branch v3.8.x ([MNT] swap xkcd script for humor sans)
* :ghpull:`27338`: Backport PR #27334 on branch v3.8.x (Omit MOVETO lines from nearest contour logic)
* :ghpull:`27299`: [MNT] swap xkcd script for humor sans
* :ghpull:`27334`: Omit MOVETO lines from nearest contour logic
* :ghpull:`27324`: Backport PR #27323 on branch v3.8.x ([DOC] Minor fixes for savefig-docstring)
* :ghpull:`27323`: [DOC] Minor fixes for savefig-docstring
* :ghpull:`27314`: Backport PR #27312 on branch v3.8.x (Doc: Step redirect)
* :ghpull:`27294`: Backport PR #27291 on branch v3.8.x (Expand 3D import to handle any exception not just ImportError)
* :ghpull:`27291`: Expand 3D import to handle any exception not just ImportError
* :ghpull:`27293`: Backport PR #27290 on branch v3.8.x (Ensure GIL while releasing buffer)
* :ghpull:`27283`: Backport PR #27280 on branch v3.8.x (DOC: added rest of licenses to license page)
* :ghpull:`27280`: DOC: added rest of licenses to license page
* :ghpull:`27278`: Backport PR #27276 on branch v3.8.x (Clarify behavior of ``prune`` parameter to MaxNLocator.)
* :ghpull:`27276`: Clarify behavior of ``prune`` parameter to MaxNLocator.
* :ghpull:`27272`: Backport PR #27271 on branch v3.8.x (DOC: minor fixes to dev workflow)
* :ghpull:`27269`: Backport PR #27268 on branch v3.8.x (Copy-edit various examples.)
* :ghpull:`27263`: Backport PR #27213 on branch v3.8.x (DOC: consolidated coding guide and added naming conventions table)
* :ghpull:`27258`: Backport PR #27249 on branch v3.8.x (DOC: reasoning for communications guidelines)
* :ghpull:`27255`: Backport PR #27253 on branch v3.8.x (Copy-edit the standalone colorbar tutorial)
* :ghpull:`27253`: Copy-edit the standalone colorbar tutorial
* :ghpull:`27252`: Backport PR #26669 on branch v3.8.x ([DOC] debug backends)
* :ghpull:`26669`: [DOC] debug backends
* :ghpull:`27250`: Backport PR #27219 on branch v3.8.x (Updated axes_box_aspect.py and angle_annotation.py to regularize formatting)
* :ghpull:`27219`: Updated axes_box_aspect.py and angle_annotation.py to regularize formatting
* :ghpull:`27247`: Backport PR #26703 on branch v3.8.x (moved communications guidelines from governance, updated and clarified process )
* :ghpull:`27246`: Backport PR #27244 on branch v3.8.x (Clarify semantics of plt.matshow(..., fignum=...).)
* :ghpull:`27244`: Clarify semantics of plt.matshow(..., fignum=...).

Issues (3):

* :ghissue:`27333`: [Bug]: Spurious lines added with some manually add contour labels
* :ghissue:`27274`: [Bug]: prune parameter of MaxNLocator has no effect
* :ghissue:`27262`: [Bug]: Segmentation fault when resizing on Python 3.12 and MacOS 14
